@@ -15,8 +15,7 @@ pg_option = typer.Option(
     ...,
     "--postges_dsn",
     help="""DSN for connection to the postgres server. Format should be:\n
-    postgresql://{ip}:{port}/{dbname}?user={username}&password={password}
-    """,
+    postgresql://{ip}:{port}/{dbname}?user={username}&password={password}""",
 )
 
 
