@@ -3,22 +3,25 @@ from asyncio.log import logging
 import os
 from pathlib import Path
 
-DB_URL = os.getenv("DATABASE_URL",
-                   'postgresql://0.0.0.0:5432/dcs?user=prod&password=pwd')
+DB_URL = os.getenv(
+    "DATABASE_URL", "postgresql://0.0.0.0:5432/dcs?user=prod&password=pwd"
+)
 
 
 def get_logger(logger_name="taview_client") -> logging.Logger:
+    """Create a package logger for tacview-client."""
     log = logging.getLogger(logger_name)
     log.setLevel(logging.INFO)
     logFormatter = logging.Formatter(
-        "%(asctime)s [%(name)s] [%(levelname)-5.5s]  %(message)s")
+        "%(asctime)s [%(name)s] [%(levelname)-5.5s]  %(message)s"
+    )
     file_path = Path(f"log/{log.name}.log")
     if not file_path.parent.exists():
         file_path.parent.mkdir()
-    if (log.hasHandlers()):
+    if log.hasHandlers():
         return log
 
-    fileHandler = logging.FileHandler(file_path, 'w')
+    fileHandler = logging.FileHandler(file_path, "w")
     fileHandler.setFormatter(logFormatter)
     log.addHandler(fileHandler)
     consoleHandler = logging.StreamHandler()
@@ -26,4 +29,3 @@ def get_logger(logger_name="taview_client") -> logging.Logger:
     log.addHandler(consoleHandler)
     log.propagate = False
     return log
-
